@@ -8,35 +8,19 @@ of temperatures that are in eV.
 
 __all__ = ["load", "utils", "write"]
 
-from . import load
-
-# assert callable(load)
-# assert callable(load.plates)
-
-
-from . import write
-
-
-# # should be deprecated
-# load.read_plate = _load.read_plate
-# load.read_plate = _load.read_plate
-# load.read_mappings = _load.read_mappings
-# load.read_mapped = _load.read_mapped
-# load.write_mapped = _load.write_mapped
-
-
+from . import load, write
 from .core.dataset import EMC3DatasetAccessor
 
 
 try:
     from importlib.metadata import (  # type: ignore
-        version as _version,
         PackageNotFoundError as _PackageNotFoundError,
+        version as _version,
     )
 except ModuleNotFoundError:
     from importlib_metadata import (  # type: ignore
-        version as _version,
         PackageNotFoundError as _PackageNotFoundError,
+        version as _version,
     )
 try:
     __version__ = _version(__name__)
